@@ -35,7 +35,7 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20050226
+#define __GLIBCXX__ 20050804
 
 // Allow use of "export template." This is currently not a feature
 // that g++ supports.
@@ -130,7 +130,7 @@ namespace std
 /* #undef _GLIBCXX_USE_WCHAR_T */
 
 // Define if using setrlimit to set resource limits during 'make check'.
-#define _GLIBCXX_RES_LIMITS 1
+/* #undef _GLIBCXX_RES_LIMITS */
 
 // Define to use concept checking code from the boost libraries.
 /* #undef _GLIBCXX_CONCEPT_CHECKS */
@@ -138,17 +138,6 @@ namespace std
 // Define to use symbol versioning in the shared library.
 /* #undef _GLIBCXX_SYMVER */
 
-// Define symbol versioning in assember directives. If symbol
-// versioning is beigng used, and the assembler supports this kind of
-// thing, then use it.
-// NB: _GLIBCXX_AT_AT is a hack to work around quoting issues in m4.
-#if _GLIBCXX_SYMVER
-  #define _GLIBCXX_ASM_SYMVER(cur, old, version) \
-   asm (".symver " #cur "," #old _GLIBCXX_AT_AT #version);
-#else
-  #define _GLIBCXX_ASM_SYMVER(cur, old, version)
-#endif
-
 // Define if LFS support is available.
 /* #undef _GLIBCXX_USE_LFS */
 
@@ -177,13 +166,13 @@ namespace std
 #define _GLIBCXX_HAVE_GETPAGESIZE 1
 
 // Define if setenv exists.
-#define _GLIBCXX_HAVE_SETENV 1
+/* #undef _GLIBCXX_HAVE_SETENV */
 
 // Define if sigsetjmp exists.
 #define _GLIBCXX_HAVE_SIGSETJMP 1
 
 // Define if mbstate_t exists in wchar.h.
-/* #undef _GLIBCXX_HAVE_MBSTATE_T */
+#define _GLIBCXX_HAVE_MBSTATE_T 1
 
 // Define if you have the modff function.
 #define _GLIBCXX_HAVE_MODFF 1
@@ -298,7 +287,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_ATANL */
 
 /* Define to 1 if you have the `btowc' function. */
-/* #undef _GLIBCXX_HAVE_BTOWC */
+#define _GLIBCXX_HAVE_BTOWC 1
 
 /* Define to 1 if you have the `ceilf' function. */
 #define _GLIBCXX_HAVE_CEILF 1
@@ -346,10 +335,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FABSL */
 
 /* Define to 1 if you have the `fgetwc' function. */
-/* #undef _GLIBCXX_HAVE_FGETWC */
+#define _GLIBCXX_HAVE_FGETWC 1
 
 /* Define to 1 if you have the `fgetws' function. */
-/* #undef _GLIBCXX_HAVE_FGETWS */
+#define _GLIBCXX_HAVE_FGETWS 1
 
 /* Define to 1 if you have the `finite' function. */
 #define _GLIBCXX_HAVE_FINITE 1
@@ -379,10 +368,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FPCLASS */
 
 /* Define to 1 if you have the `fputwc' function. */
-/* #undef _GLIBCXX_HAVE_FPUTWC */
+#define _GLIBCXX_HAVE_FPUTWC 1
 
 /* Define to 1 if you have the `fputws' function. */
-/* #undef _GLIBCXX_HAVE_FPUTWS */
+#define _GLIBCXX_HAVE_FPUTWS 1
 
 /* Define to 1 if you have the <fp.h> header file. */
 /* #undef _GLIBCXX_HAVE_FP_H */
@@ -394,7 +383,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FREXPL */
 
 /* Define to 1 if you have the `fwide' function. */
-/* #undef _GLIBCXX_HAVE_FWIDE */
+#define _GLIBCXX_HAVE_FWIDE 1
 
 /* Define to 1 if you have the `fwprintf' function. */
 /* #undef _GLIBCXX_HAVE_FWPRINTF */
@@ -409,10 +398,10 @@ namespace std
 #define _GLIBCXX_HAVE_GETPAGESIZE 1
 
 /* Define to 1 if you have the `getwc' function. */
-/* #undef _GLIBCXX_HAVE_GETWC */
+#define _GLIBCXX_HAVE_GETWC 1
 
 /* Define to 1 if you have the `getwchar' function. */
-/* #undef _GLIBCXX_HAVE_GETWCHAR */
+#define _GLIBCXX_HAVE_GETWCHAR 1
 
 /* Define to 1 if you have the `hypot' function. */
 #define _GLIBCXX_HAVE_HYPOT 1
@@ -457,7 +446,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_ISNANL */
 
 /* Define to 1 if you have the `iswblank' function. */
-/* #undef _GLIBCXX_HAVE_ISWBLANK */
+#define _GLIBCXX_HAVE_ISWBLANK 1
 
 /* Define to 1 if you have the `ldexpf' function. */
 #define _GLIBCXX_HAVE_LDEXPF 1
@@ -472,19 +461,19 @@ namespace std
 #define _GLIBCXX_HAVE_LIBM 1
 
 /* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_LIMIT_AS 0
+/* #undef _GLIBCXX_HAVE_LIMIT_AS */
 
 /* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_LIMIT_DATA 1
+/* #undef _GLIBCXX_HAVE_LIMIT_DATA */
 
 /* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_LIMIT_FSIZE 1
+/* #undef _GLIBCXX_HAVE_LIMIT_FSIZE */
 
 /* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_LIMIT_RSS 1
+/* #undef _GLIBCXX_HAVE_LIMIT_RSS */
 
 /* Only used in build directory testsuite_hooks.h. */
-#define _GLIBCXX_HAVE_LIMIT_VMEM 0
+/* #undef _GLIBCXX_HAVE_LIMIT_VMEM */
 
 /* Define to 1 if you have the <locale.h> header file. */
 #define _GLIBCXX_HAVE_LOCALE_H 1
@@ -508,16 +497,16 @@ namespace std
 #define _GLIBCXX_HAVE_MACHINE_PARAM_H 1
 
 /* Define to 1 if you have the `mbrlen' function. */
-/* #undef _GLIBCXX_HAVE_MBRLEN */
+#define _GLIBCXX_HAVE_MBRLEN 1
 
 /* Define to 1 if you have the `mbrtowc' function. */
-/* #undef _GLIBCXX_HAVE_MBRTOWC */
+#define _GLIBCXX_HAVE_MBRTOWC 1
 
 /* Define to 1 if you have the `mbsinit' function. */
-/* #undef _GLIBCXX_HAVE_MBSINIT */
+#define _GLIBCXX_HAVE_MBSINIT 1
 
 /* Define to 1 if you have the `mbsrtowcs' function. */
-/* #undef _GLIBCXX_HAVE_MBSRTOWCS */
+#define _GLIBCXX_HAVE_MBSRTOWCS 1
 
 /* Define to 1 if you have the <memory.h> header file. */
 #define _GLIBCXX_HAVE_MEMORY_H 1
@@ -535,7 +524,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_NAN_H */
 
 /* Define to 1 if you have the `nl_langinfo' function. */
-/* #undef _GLIBCXX_HAVE_NL_LANGINFO */
+#define _GLIBCXX_HAVE_NL_LANGINFO 1
 
 /* Define to 1 if you have the `powf' function. */
 #define _GLIBCXX_HAVE_POWF 1
@@ -544,16 +533,16 @@ namespace std
 /* #undef _GLIBCXX_HAVE_POWL */
 
 /* Define to 1 if you have the `putwc' function. */
-/* #undef _GLIBCXX_HAVE_PUTWC */
+#define _GLIBCXX_HAVE_PUTWC 1
 
 /* Define to 1 if you have the `putwchar' function. */
-/* #undef _GLIBCXX_HAVE_PUTWCHAR */
+#define _GLIBCXX_HAVE_PUTWCHAR 1
 
 /* Define to 1 if you have the `qfpclass' function. */
 /* #undef _GLIBCXX_HAVE_QFPCLASS */
 
 /* Define to 1 if you have the `setenv' function. */
-#define _GLIBCXX_HAVE_SETENV 1
+/* #undef _GLIBCXX_HAVE_SETENV */
 
 /* Define if sigsetjmp is available. */
 #define _GLIBCXX_HAVE_SIGSETJMP 1
@@ -628,7 +617,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_SYS_PARAM_H */
 
 /* Define to 1 if you have the <sys/resource.h> header file. */
-#define _GLIBCXX_HAVE_SYS_RESOURCE_H 1
+/* #undef _GLIBCXX_HAVE_SYS_RESOURCE_H */
 
 /* Define to 1 if you have the <sys/sem.h> header file. */
 #define _GLIBCXX_HAVE_SYS_SEM_H 1
@@ -637,7 +626,7 @@ namespace std
 #define _GLIBCXX_HAVE_SYS_STAT_H 1
 
 /* Define to 1 if you have the <sys/time.h> header file. */
-#define _GLIBCXX_HAVE_SYS_TIME_H 1
+/* #undef _GLIBCXX_HAVE_SYS_TIME_H */
 
 /* Define to 1 if you have the <sys/types.h> header file. */
 #define _GLIBCXX_HAVE_SYS_TYPES_H 1
@@ -658,7 +647,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_TANL */
 
 /* Define to 1 if you have the `ungetwc' function. */
-/* #undef _GLIBCXX_HAVE_UNGETWC */
+#define _GLIBCXX_HAVE_UNGETWC 1
 
 /* Define to 1 if you have the <unistd.h> header file. */
 #define _GLIBCXX_HAVE_UNISTD_H 1
@@ -682,97 +671,97 @@ namespace std
 /* #undef _GLIBCXX_HAVE_VWSCANF */
 
 /* Define to 1 if you have the <wchar.h> header file. */
-/* #undef _GLIBCXX_HAVE_WCHAR_H */
+#define _GLIBCXX_HAVE_WCHAR_H 1
 
 /* Define to 1 if you have the `wcrtomb' function. */
-/* #undef _GLIBCXX_HAVE_WCRTOMB */
+#define _GLIBCXX_HAVE_WCRTOMB 1
 
 /* Define to 1 if you have the `wcscat' function. */
-/* #undef _GLIBCXX_HAVE_WCSCAT */
+#define _GLIBCXX_HAVE_WCSCAT 1
 
 /* Define to 1 if you have the `wcschr' function. */
-/* #undef _GLIBCXX_HAVE_WCSCHR */
+#define _GLIBCXX_HAVE_WCSCHR 1
 
 /* Define to 1 if you have the `wcscmp' function. */
-/* #undef _GLIBCXX_HAVE_WCSCMP */
+#define _GLIBCXX_HAVE_WCSCMP 1
 
 /* Define to 1 if you have the `wcscoll' function. */
-/* #undef _GLIBCXX_HAVE_WCSCOLL */
+#define _GLIBCXX_HAVE_WCSCOLL 1
 
 /* Define to 1 if you have the `wcscpy' function. */
-/* #undef _GLIBCXX_HAVE_WCSCPY */
+#define _GLIBCXX_HAVE_WCSCPY 1
 
 /* Define to 1 if you have the `wcscspn' function. */
-/* #undef _GLIBCXX_HAVE_WCSCSPN */
+#define _GLIBCXX_HAVE_WCSCSPN 1
 
 /* Define to 1 if you have the `wcsftime' function. */
 /* #undef _GLIBCXX_HAVE_WCSFTIME */
 
 /* Define to 1 if you have the `wcslen' function. */
-/* #undef _GLIBCXX_HAVE_WCSLEN */
+#define _GLIBCXX_HAVE_WCSLEN 1
 
 /* Define to 1 if you have the `wcsncat' function. */
-/* #undef _GLIBCXX_HAVE_WCSNCAT */
+#define _GLIBCXX_HAVE_WCSNCAT 1
 
 /* Define to 1 if you have the `wcsncmp' function. */
-/* #undef _GLIBCXX_HAVE_WCSNCMP */
+#define _GLIBCXX_HAVE_WCSNCMP 1
 
 /* Define to 1 if you have the `wcsncpy' function. */
-/* #undef _GLIBCXX_HAVE_WCSNCPY */
+#define _GLIBCXX_HAVE_WCSNCPY 1
 
 /* Define to 1 if you have the `wcspbrk' function. */
-/* #undef _GLIBCXX_HAVE_WCSPBRK */
+#define _GLIBCXX_HAVE_WCSPBRK 1
 
 /* Define to 1 if you have the `wcsrchr' function. */
-/* #undef _GLIBCXX_HAVE_WCSRCHR */
+#define _GLIBCXX_HAVE_WCSRCHR 1
 
 /* Define to 1 if you have the `wcsrtombs' function. */
-/* #undef _GLIBCXX_HAVE_WCSRTOMBS */
+#define _GLIBCXX_HAVE_WCSRTOMBS 1
 
 /* Define to 1 if you have the `wcsspn' function. */
-/* #undef _GLIBCXX_HAVE_WCSSPN */
+#define _GLIBCXX_HAVE_WCSSPN 1
 
 /* Define to 1 if you have the `wcsstr' function. */
-/* #undef _GLIBCXX_HAVE_WCSSTR */
+#define _GLIBCXX_HAVE_WCSSTR 1
 
 /* Define to 1 if you have the `wcstod' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOD */
+#define _GLIBCXX_HAVE_WCSTOD 1
 
 /* Define to 1 if you have the `wcstof' function. */
 /* #undef _GLIBCXX_HAVE_WCSTOF */
 
 /* Define to 1 if you have the `wcstok' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOK */
+#define _GLIBCXX_HAVE_WCSTOK 1
 
 /* Define to 1 if you have the `wcstol' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOL */
+#define _GLIBCXX_HAVE_WCSTOL 1
 
 /* Define to 1 if you have the `wcstoul' function. */
-/* #undef _GLIBCXX_HAVE_WCSTOUL */
+#define _GLIBCXX_HAVE_WCSTOUL 1
 
 /* Define to 1 if you have the `wcsxfrm' function. */
-/* #undef _GLIBCXX_HAVE_WCSXFRM */
+#define _GLIBCXX_HAVE_WCSXFRM 1
 
 /* Define to 1 if you have the `wctob' function. */
-/* #undef _GLIBCXX_HAVE_WCTOB */
+#define _GLIBCXX_HAVE_WCTOB 1
 
 /* Define to 1 if you have the <wctype.h> header file. */
-/* #undef _GLIBCXX_HAVE_WCTYPE_H */
+#define _GLIBCXX_HAVE_WCTYPE_H 1
 
 /* Define to 1 if you have the `wmemchr' function. */
-/* #undef _GLIBCXX_HAVE_WMEMCHR */
+#define _GLIBCXX_HAVE_WMEMCHR 1
 
 /* Define to 1 if you have the `wmemcmp' function. */
-/* #undef _GLIBCXX_HAVE_WMEMCMP */
+#define _GLIBCXX_HAVE_WMEMCMP 1
 
 /* Define to 1 if you have the `wmemcpy' function. */
-/* #undef _GLIBCXX_HAVE_WMEMCPY */
+#define _GLIBCXX_HAVE_WMEMCPY 1
 
 /* Define to 1 if you have the `wmemmove' function. */
-/* #undef _GLIBCXX_HAVE_WMEMMOVE */
+#define _GLIBCXX_HAVE_WMEMMOVE 1
 
 /* Define to 1 if you have the `wmemset' function. */
-/* #undef _GLIBCXX_HAVE_WMEMSET */
+#define _GLIBCXX_HAVE_WMEMSET 1
 
 /* Define to 1 if you have the `wprintf' function. */
 /* #undef _GLIBCXX_HAVE_WPRINTF */
@@ -999,6 +988,12 @@ namespace std
 /* Define to 1 if a full hosted library is built, or 0 if freestanding. */
 #define _GLIBCXX_HOSTED 1
 
+/* Define if ptrdiff_t is int. */
+#define _GLIBCXX_PTRDIFF_T_IS_INT 1
+
+/* Define if size_t is unsigned int. */
+#define _GLIBCXX_SIZE_T_IS_UINT 1
+
 /* Define if the compiler is configured for setjmp/longjmp exceptions. */
 #define _GLIBCXX_SJLJ_EXCEPTIONS 1
 //
